package com.yidianling.user.ui.login

import android.annotation.SuppressLint
import android.os.Build
import android.os.Handler
import android.text.Html
import android.view.KeyEvent
import com.ydl.ydlcommon.base.BaseActivity
import com.ydl.ydlcommon.utils.ActivityManager
import com.ydl.ydlcommon.utils.SharedPreferencesEditor
import com.ydl.ydlcommon.utils.StatusBarUtils
import com.yidianling.common.tools.ToastUtil
import com.yidianling.user.R
import com.yidianling.user.http.UserHttpImpl
import com.yidianling.user.widget.SecretDialog
import io.reactivex.android.schedulers.AndroidSchedulers
import io.reactivex.schedulers.Schedulers
import kotlinx.android.synthetic.main.user_activity_secret.*
import kotlin.system.exitProcess

/**
 * 隐私界面
 * author : Zhangwenchao
 * e-mail : zhangwch@yidianling.com
 * time   : 2018/01/10
 */
class SecretActivity : BaseActivity() {

    private var secretDialog: SecretDialog? = null

    override fun layoutResId(): Int {
        return R.layout.user_activity_secret
    }

    override fun initDataAndEvent() {
        initView()
    }

    private fun initView() {

        initStatus()

        initData()

        user_secret_no_agree.setOnClickListener {
            if (null == secretDialog) {
                secretDialog = SecretDialog(this, object : SecretDialog.OnSecretDialogListener {
                    override fun onCancel() {
                        Handler().postDelayed({
                            ActivityManager.finishAll()
                            android.os.Process.killProcess(android.os.Process.myPid())
                            exitProcess(0)
                        }, 1000)
                    }

                    override fun onSure() {
                        agreeAction()
                    }
                })
                secretDialog?.show()
            } else {
                secretDialog?.show()
            }
        }

        user_secret_agree.setOnClickListener {
            agreeAction()
        }

        user_use_btn.setOnClickListener {
            H5Activity.start(this@SecretActivity, false)
        }

        user_secret_protect_btn.setOnClickListener {
            H5Activity.start(this@SecretActivity, true)
        }
    }

    @SuppressLint("CheckResult")
    private fun initData() {
        UserHttpImpl.getInstance().getSecretData()
            .subscribeOn(Schedulers.io())
            .observeOn(AndroidSchedulers.mainThread())
            .doOnSubscribe { (this as BaseActivity).showProgressDialog() }
            .doAfterTerminate {
                (this as BaseActivity).dismissProgressDialog()
            }
            .subscribe({
                if (it.code == 0) {
                    if (null != user_secret_desc) {
                        user_secret_desc.text = Html.fromHtml(it.data)
                    }
                }
            }, {
                ToastUtil.toastShort(R.string.platform_network_error)
            })
    }

    override fun onKeyDown(keyCode: Int, event: KeyEvent): Boolean {
        if (keyCode == KeyEvent.KEYCODE_BACK) {
            return false
        }
        return super.onKeyDown(keyCode, event)
    }

    private fun initStatus() {
        if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.KITKAT) {//4.4以下不支持状态栏变色
            StatusBarUtils.setTransparentForImageView(this, null)
            StatusBarUtils.statusBarLightMode(this)
        }
    }

    private fun agreeAction() {
        SharedPreferencesEditor.putString("hasAgreeSecret", "true")
        finish()
    }
}